import 'dart:io' as io;
import 'package:simple_http_router/http_router.dart';
import 'lib/middleware/session.dart';
import 'lib/handler/index.dart';
import 'lib/handler/not_found.dart';

const port = 8080;
const address = 'localhost';

void logRequest(io.HttpRequest req) {
  print('${req.method}: ${req.uri}');
}

void main(List<String> args) async {
  final server = await io.HttpServer.bind(address, port);
  print('Listening on http://${address}:${port}');

  final router = HttpRouter(notFoundHandler: siteNotFoundHandler);
  router.register('/', get: indexHandler);
  router.register('/index', get: indexHandler);

  final cookieRouter = router.child(before: [setCookie]);
  cookieRouter.register('/cookie', get: indexHandler);

  await for (final request in server) {
    logRequest(request);
    try {
      router.handleRequest(request);
    } catch (e) {
      print(e);
      request.response.statusCode = io.HttpStatus.internalServerError;
      request.response.writeln(request.response.reasonPhrase);
      //ignore:unawaited_futures
      request.response.close();
    }
  }
}
